/**
 * Copyright (c) 2011-2012 INRIA.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>
 **/
package fr.inria.eventcloud.webservices.services;

import fr.inria.eventcloud.translators.wsn.WsnTranslator;

/**
 * Extends {@link EventCloudProxyService} by providing an instance of
 * {@link WsnTranslator}. This is usefull for proxies exposed as a web service
 * which have to translate some payloads.
 * 
 * @author lpellegr
 * 
 * @param <T>
 *            proxy type.
 */
public abstract class EventCloudTranslatableProxyService<T> extends
        EventCloudProxyService<T> {

    protected final WsnTranslator translator;

    public EventCloudTranslatableProxyService(String registryUrl,
            String eventcloudUrl) {
        super(registryUrl, eventcloudUrl);
        this.translator = new WsnTranslator();
    }

    protected static final void logAndThrowIllegalArgumentException(String msg) {
        log.error(msg);
        throw new IllegalArgumentException(msg);
    }

}
